==> ejc-ztpczr-impl-3.0.0-20231219.012649-36-sources.jar: com/ejianc/business/ztpczr/controller/OtherController.java <==
package com.ejianc.business.ztpczr.controller;

import com.ejianc.business.ztpczr.jwt.IJWTInfo;
import com.ejianc.business.ztpczr.jwt.JWTHelper;
import com.ejianc.business.ztpczr.service.impl.JwtServiceImpl;
import com.ejianc.framework.core.response.CommonResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.Serializable;

/**
 * CVAR
 *
 * @author generator
 *
 */
@RestController
@RequestMapping("/other")
public class OtherController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private JwtServiceImpl jwtService;

    /**
     * 获取主数据分页内容
     *
     * @author lijunxue
     * @date 2023/7/10 13:09
     */
    @GetMapping("/jump")
    @ResponseBody
    public void jumpUrl(HttpServletRequest request, HttpServletResponse response , @RequestParam(value = "pageCode") String pageCode) throws Exception {
        // 获取用户的手机号
        // 获取用户的工号
        // 生成token 的方法 这个一会提供
        // 拼接成一个地址 url 需要appCode 和 pageCode
        // 访问url
        String s = jwtService.generateToken();
        System.out.println(s+"你好你好你好");
        response.addHeader("kt",s);
        response.sendRedirect("https://dev.ztpc.com/sys/thirdLogin/yql/jump? tenantId=FEBD411AA2E8E028CEE2&appCode=56375806efbf754d87e12e3476c22cb7&pageCode="+pageCode);
//        response.sendRedirect("https://blog.csdn.net/jianguang01/article/details/"+pageCode);
    }

    @GetMapping("/jumpUrl")
    @ResponseBody
    public CommonResponse<String> jumpUrls(HttpServletRequest request, HttpServletResponse response , @RequestParam(value = "pageCode") String pageCode) throws Exception {
        // 获取用户的手机号
        // 获取用户的工号
        // 生成token 的方法 这个一会提供
        // 拼接成一个地址 url 需要appCode 和 pageCode
        // 访问url
        String s = jwtService.generateToken();
        System.out.println(s+"你好你好你好");
        response.addHeader("kt",s);
        response.sendRedirect("https://dev.ztpc.com/sys/thirdLogin/yql/jump?appCode=56375806efbf754d87e12e3476c22cb7&pageCode="+pageCode);
//        response.sendRedirect("https://blog.csdn.net/jianguang01/article/details/"+pageCode);
        String s1="https://dev.ztpc.com/sys/thirdLogin/yql/jump?appCode=56375806efbf754d87e12e3476c22cb7&pageCode="+pageCode+"&kt="+s;
        return CommonResponse.success(s1);
    }


}

==> ejc-ztpczr-impl-3.0.0-20231219.024225-38-sources.jar: com/ejianc/business/ztpczr/controller/OtherController.java <==
package com.ejianc.business.ztpczr.controller;

import com.ejianc.business.ztpczr.jwt.IJWTInfo;
import com.ejianc.business.ztpczr.jwt.JWTHelper;
import com.ejianc.business.ztpczr.service.impl.JwtServiceImpl;
import com.ejianc.framework.core.response.CommonResponse;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.Serializable;

/**
 * CVAR
 *
 * @author generator
 *
 */
@RestController
@RequestMapping("/other")
public class OtherController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private JwtServiceImpl jwtService;

    /**
     * 获取主数据分页内容
     *
     * @author lijunxue
     * @date 2023/7/10 13:09
     */
    @GetMapping("/jump")
    @ResponseBody
    public void jumpUrl(HttpServletRequest request, HttpServletResponse response , @RequestParam(value = "pageCode") String pageCode) throws Exception {
        // 获取用户的手机号
        // 获取用户的工号
        // 生成token 的方法 这个一会提供
        // 拼接成一个地址 url 需要appCode 和 pageCode
        // 访问url
//        String s = jwtService.generateToken();
//        response.addHeader("kt",s);
//        response.sendRedirect("https://dev.ztpc.com/sys/thirdLogin/yql/jump? tenantId=FEBD411AA2E8E028CEE2&appCode=56375806efbf754d87e12e3476c22cb7&pageCode="+pageCode);
        response.sendRedirect("https://blog.csdn.net/jianguang01/article/details/"+pageCode);
    }

    @GetMapping("/jumpUrl")
    @ResponseBody
    public CommonResponse<String> jumpUrls(HttpServletRequest request, HttpServletResponse response , @RequestParam(value = "pageCode") String pageCode) throws Exception {
        // 获取用户的手机号
        // 获取用户的工号
        // 生成token 的方法 这个一会提供
        // 拼接成一个地址 url 需要appCode 和 pageCode
        // 访问url
//        String s = jwtService.generateToken();
//        response.addHeader("kt",s);
//        response.sendRedirect("https://blog.csdn.net/jianguang01/article/details/"+pageCode);
//        String s1="https://dev.ztpc.com/sys/thirdLogin/yql/jump?appCode=56375806efbf754d87e12e3476c22cb7&pageCode="+pageCode+"&kt="+s;
        String s1="https://blog.csdn.net/jianguang01/article/details/"+pageCode;
        return CommonResponse.success(s1);
    }


}
